## :memo: Changelog

- [x] the first change
- [x] the second change

## :link: Links

  - [Gitlab issue](link into issue)

## :white_check_mark: Checklist

- [ ] Lint and tests pass locally with my changes
- [ ] I've added tests that prove my feature works or that my fix is effective
- [ ] I've added necessary documentation
